@@ -11,7 +11,7 @@ package Pod::Weaver::PluginBundle::RSRCHBOY;
 BEGIN {
   $Pod::Weaver::PluginBundle::RSRCHBOY::AUTHORITY = 'cpan:RSRCHBOY';
 }
-$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.047';
+$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.048';
 # ABSTRACT: Document your modules like RSRCHBOY does
 
 use strict;
@@ -31,8 +31,8 @@ sub mvp_bundle_config {
         [ '@RSRCHBOY/StopWords', _exp('-StopWords'), {} ],
         [ '@RSRCHBOY/CorePrep',  _exp('@CorePrep'),  {} ],
         _exp2('Name'),
-        [ '@RSRCHBOY/Version', _exp('Version'),      { format      => $vformat  } ],
-        [ '@RSRCHBOY/prelude', _exp('Region'),      { region_name => 'prelude' } ],
+        [ '@RSRCHBOY/Version', _exp('Version'), { format      => $vformat  } ],
+        [ '@RSRCHBOY/prelude', _exp('Region'),  { region_name => 'prelude' } ],
 
         [ 'SYNOPSIS',         _exp('Generic'),      {} ],
         [ 'DESCRIPTION',      _exp('Generic'),      {} ],
@@ -58,7 +58,7 @@ sub mvp_bundle_config {
         _exp2('SourceGitHub'),
         _exp2('Bugs'),
 
-        _exp2('Authors'),
+        [ 'RSRCHBOY::Authors',     _exp('RSRCHBOY::Authors'),     { } ],
         _exp2('Contributors'),
         _exp2('Legal'),
 
@@ -75,7 +75,9 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl Bowers Neil Romanov Sergey
+=for :stopwords Chris Weyl Neil Bowers Sergey Romanov
+
+=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
 =head1 NAME
 
@@ -83,7 +85,7 @@ Pod::Weaver::PluginBundle::RSRCHBOY - Document your modules like RSRCHBOY does
 
 =head1 VERSION
 
-This document describes version 0.047 of Pod::Weaver::PluginBundle::RSRCHBOY - released April 17, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.048 of Pod::Weaver::PluginBundle::RSRCHBOY - released April 29, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -103,7 +105,7 @@ documentation.
 
 =head1 OVERVIEW
 
-This plugin bundle is equivalent to the following weaver.ini file:
+This plugin bundle is B<ROUGHLY> equivalent to the following weaver.ini file:
 
   [@CorePrep]
 
@@ -174,6 +176,17 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head2 SAYING THANKS IN A MATERIALISTIC WAY
+
+Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
+rather B<it is simply a very pleasant surprise>. I largely create and release
+works like this because I need them or I find it enjoyable; however, don't let
+that stop you giving me money if you feel like it ;)
+
+L<flattr this!|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-rsrchboy&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-RSRCHBOY&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-RSRCHBOY%20in%20the%20CPAN%22>
+L<gittip me!|https://www.gittip.com/RsrchBoy/>
+L<Amazon Wishlist|http://www.amazon.com/gp/registry/wishlist/3G2DQFPBA57L6>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by Chris Weyl.
